bottomNavClearance constant
double
const bottomNavClearance
Useful when a scrollable screen needs clearance above a bottom navbar.
Implementation
static const double bottomNavClearance = 96.0;
Useful when a scrollable screen needs clearance above a bottom navbar.
static const double bottomNavClearance = 96.0;