KiteDialog class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

confirm(BuildContext context, {required String title, required String message, String cancelLabel = 'Cancel', String confirmLabel = 'Confirm', bool destructive = false}) Future<bool>
show<T>(BuildContext context, {required String title, required Widget content, Widget? icon, List<Widget> actions = const [], bool barrierDismissible = true, String? description}) Future<T?>