KiteResponsiveData class
- Annotations
Constructors
- KiteResponsiveData({required KiteLayoutSize size, required double width})
-
const
Properties
- compact → bool
-
no setter
- expanded → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- medium → bool
-
no setter
- pageInsets → EdgeInsets
-
no setter
- pagePadding → double
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → KiteLayoutSize
-
final
- wide → bool
-
no setter
- width → double
-
final
Methods
-
columns(
{int compact = 1, int medium = 2, int expanded = 3}) → int -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
value<
T> ({required T compact, T? medium, T? expanded}) → T
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited