Built with Kite 🪁 Flutter foundations, architecture, and developer tooling. Learn more: https://kite.orkitt.dev
Centralized application dimensions, paddings, radiuses, and layout gaps.
Based primarily on a 4px grid system.
Naming conventions:
s16→ Raw spacing valuer16→ Raw radius valuerad16→ BorderRadiusp16→ EdgeInsets.all()px16→ Horizontal paddingpy16→ Vertical paddingvBox16→ Vertical gaphBox16→ Horizontal gap
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- appBarHeight → const double
- Standard top app bar height.
- avatarLg → const double
- avatarMd → const double
- avatarSm → const double
- avatarXl → const double
- avatarXs → const double
- avatarXxl → const double
- badgeLg → const double
- badgeMd → const double
- badgeSm → const double
- borderDefault → const double
- borderStrong → const double
- borderThin → const double
- Useful when a scrollable screen needs clearance above a bottom navbar.
- bottomSheetPadding → const EdgeInsets
- Bottom sheet content padding.
- cardPadding → const EdgeInsets
- Common card internal padding.
- cardPaddingLg → const EdgeInsets
- Spacious card internal padding.
- checkboxSize → const double
- chipHeight → const double
- contentMaxWidth → const double
- Standard content width.
- dialogMaxWidth → const double
- Common dialog max width.
- dialogPadding → const EdgeInsets
- Dialog / modal internal padding.
- dividerThickness → const double
- drawerWidth → const double
- Common drawer width.
- fabLg → const double
- fabMd → const double
- fabSm → const double
- formMaxWidth → const double
- Useful for authentication/forms on tablet and desktop.
- hBox2 → const SizedBox
- hBox4 → const SizedBox
- hBox8 → const SizedBox
- hBox12 → const SizedBox
- hBox16 → const SizedBox
- hBox20 → const SizedBox
- hBox24 → const SizedBox
- hBox28 → const SizedBox
- hBox32 → const SizedBox
- hBox40 → const SizedBox
- hBox48 → const SizedBox
- hBox56 → const SizedBox
- hBox64 → const SizedBox
- iconLg → const double
- iconMd → const double
- iconSm → const double
- iconXl → const double
- iconXs → const double
- iconXxl → const double
- imagePreviewMd → const double
- imagePreviewSm → const double
- indicatorLg → const double
- indicatorMd → const double
- indicatorSm → const double
- inputHeightLg → const double
- inputHeightMd → const double
- inputHeightSm → const double
- Standard Material 3 Navigation Bar height.
- More compact custom bottom navigation.
- offsetLg → const double
- offsetMd → const double
- offsetSm → const double
- Common small elevation-like vertical offset.
- p2 → const EdgeInsets
- p4 → const EdgeInsets
- p8 → const EdgeInsets
- p12 → const EdgeInsets
- p16 → const EdgeInsets
- p20 → const EdgeInsets
- p24 → const EdgeInsets
- p28 → const EdgeInsets
- p32 → const EdgeInsets
- p40 → const EdgeInsets
- p48 → const EdgeInsets
- progressStrokeLg → const double
- progressStrokeMd → const double
- progressStrokeSm → const double
- px4 → const EdgeInsets
- px8 → const EdgeInsets
- px8y4 → const EdgeInsets
- px12 → const EdgeInsets
- px12y8 → const EdgeInsets
- px16 → const EdgeInsets
- px16y4 → const EdgeInsets
- px16y8 → const EdgeInsets
- px16y12 → const EdgeInsets
- px16y20 → const EdgeInsets
- px20 → const EdgeInsets
- px20y8 → const EdgeInsets
- px20y12 → const EdgeInsets
- px20y16 → const EdgeInsets
- px24 → const EdgeInsets
- px24y8 → const EdgeInsets
- px24y12 → const EdgeInsets
- px24y16 → const EdgeInsets
- px24y20 → const EdgeInsets
- px28 → const EdgeInsets
- px32 → const EdgeInsets
- px32y16 → const EdgeInsets
- px32y24 → const EdgeInsets
- px40 → const EdgeInsets
- px48 → const EdgeInsets
- py4 → const EdgeInsets
- py8 → const EdgeInsets
- py12 → const EdgeInsets
- py16 → const EdgeInsets
- py20 → const EdgeInsets
- py24 → const EdgeInsets
- py28 → const EdgeInsets
- py32 → const EdgeInsets
- py40 → const EdgeInsets
- py48 → const EdgeInsets
- pZero → const EdgeInsets
- r4 → const double
- r8 → const double
- r12 → const double
- r16 → const double
- r20 → const double
- r24 → const double
- r28 → const double
- r32 → const double
- r40 → const double
- r48 → const double
- rad4 → const BorderRadius
- rad8 → const BorderRadius
- rad12 → const BorderRadius
- rad16 → const BorderRadius
- rad20 → const BorderRadius
- rad24 → const BorderRadius
- rad28 → const BorderRadius
- rad32 → const BorderRadius
- rad40 → const BorderRadius
- rad48 → const BorderRadius
- radFull → const BorderRadius
- radioSize → const double
- radZero → const BorderRadius
- railExtendedWidth → const double
- Extended navigation rail width.
- railWidth → const double
- Standard navigation rail width.
- readableContentMaxWidth → const double
- Narrow readable content.
- rFull → const double
- s2 → const double
- s4 → const double
- s8 → const double
- s12 → const double
- s16 → const double
- s20 → const double
- s24 → const double
- s28 → const double
- s32 → const double
- s36 → const double
- s40 → const double
- s44 → const double
- s48 → const double
- s52 → const double
- s56 → const double
- s60 → const double
- s64 → const double
- s72 → const double
- s80 → const double
- s88 → const double
- s96 → const double
- s104 → const double
- s112 → const double
- s120 → const double
- s128 → const double
- screenInsets → const EdgeInsets
- Default mobile page content padding.
- screenInsetsComfortable → const EdgeInsets
- Slightly more spacious page padding.
- screenPadding → const double
- Default screen padding.
- screenPaddingLg → const double
- Comfortable screen padding for larger phones/tablets.
- segmentedControlHeight → const double
- Compact sidebar width.
- switchHeight → const double
- thumbnailLg → const double
- thumbnailMd → const double
- thumbnailSm → const double
- toolbarHeight → const double
- Flutter's standard toolbar height.
- touchTarget → const double
- touchTargetLg → const double
- touchTargetSm → const double
- vBox2 → const SizedBox
- vBox4 → const SizedBox
- vBox8 → const SizedBox
- vBox12 → const SizedBox
- vBox16 → const SizedBox
- vBox20 → const SizedBox
- vBox24 → const SizedBox
- vBox28 → const SizedBox
- vBox32 → const SizedBox
- vBox36 → const SizedBox
- vBox40 → const SizedBox
- vBox48 → const SizedBox
- vBox56 → const SizedBox
- vBox64 → const SizedBox
- vBox72 → const SizedBox
- vBox80 → const SizedBox
- vBox96 → const SizedBox
- zero → const double