Dimensions class abstract final

Built with Kite 🪁 Flutter foundations, architecture, and developer tooling. Learn more: https://kite.orkitt.dev Centralized application dimensions, paddings, radiuses, and layout gaps.

Based on an 4px grid system.

Naming Conventions:

  • s16 → Raw spacing value (double)
  • r16 → Raw radius value (double)
  • rad16BorderRadius
  • p16EdgeInsets.all()
  • px16EdgeInsets.symmetric(horizontal: ...)
  • py16EdgeInsets.symmetric(vertical: ...)
  • gapV16 → Vertical gap (SizedBox(height: ...))
  • gapH16 → Horizontal gap (SizedBox(width: ...))

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

appBarHeight → const double
Standard Top App Bar height.
buttonHeightLg → const double
buttonHeightMd → const double
buttonHeightSm → const double
gapH4 → const SizedBox
gapH8 → const SizedBox
gapH12 → const SizedBox
gapH16 → const SizedBox
gapH20 → const SizedBox
gapH24 → const SizedBox
gapH32 → const SizedBox
gapV4 → const SizedBox
gapV8 → const SizedBox
gapV12 → const SizedBox
gapV16 → const SizedBox
gapV20 → const SizedBox
gapV24 → const SizedBox
gapV32 → const SizedBox
gapV40 → const SizedBox
gapV48 → const SizedBox
gapV64 → const SizedBox
iconLg → const double
iconMd → const double
iconSm → const double
Standard Material 3 Navigation Bar height (Bottom Navigation).
p4 → const EdgeInsets
p8 → const EdgeInsets
p12 → const EdgeInsets
p16 → const EdgeInsets
p20 → const EdgeInsets
p24 → const EdgeInsets
p32 → const EdgeInsets
px8 → const EdgeInsets
px12 → const EdgeInsets
px16 → const EdgeInsets
px16y8 → const EdgeInsets
px16y12 → const EdgeInsets
px20 → const EdgeInsets
px20y16 → const EdgeInsets
px24 → const EdgeInsets
px32 → const EdgeInsets
py4 → const EdgeInsets
py8 → const EdgeInsets
py12 → const EdgeInsets
py16 → const EdgeInsets
py20 → const EdgeInsets
py24 → const EdgeInsets
pZero → const EdgeInsets
r4 → const double
r8 → const double
r12 → const double
r16 → const double
r20 → const double
r24 → const double
r32 → const double
rad4 → const BorderRadius
rad8 → const BorderRadius
rad12 → const BorderRadius
rad16 → const BorderRadius
rad20 → const BorderRadius
rad24 → const BorderRadius
rad32 → const BorderRadius
radFull → const BorderRadius
radZero → const BorderRadius
railExtendedWidth → const double
Extended Navigation Rail width (expanded state with labels).
railWidth → const double
Compact Navigation Rail width (collapsed state).
rFull → const double
s2 → const double
s4 → const double
s8 → const double
s12 → const double
s16 → const double
s20 → const double
s24 → const double
s32 → const double
s40 → const double
s48 → const double
s64 → const double
screenPadding → const double
Default screen padding (margin from edge of device).
touchTarget → const double
zero → const double