KiteColors class
Built with Kite 🪁 Flutter foundations, architecture, and developer tooling. Learn more: https://kite.orkitt.dev
- Inheritance
-
- Object
- ThemeExtension<
KiteColors> - KiteColors
- Annotations
Constructors
- KiteColors({required Color primary, required Color onPrimary, required Color secondary, required Color onSecondary, required Color background, required Color card, required Color muted, required Color inputFill, required Color border, required Color textPrimary, required Color textSecondary, required Color textDisabled, required Color icon, required Color success, required Color warning, required Color error, required Color info})
-
const
Properties
- background → Color
-
Main application/page background.
final
- border → Color
-
The single source of truth for the application's border family.
final
- borderSoft → Color
-
Low-emphasis border.
no setter
- borderStrong → Color
-
High-emphasis neutral border.
no setter
- card → Color
-
Main card, sheet, dialog, and content container background.
final
- error → Color
-
final
- errorSoft → Color
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Color
-
final
- info → Color
-
final
- infoSoft → Color
-
no setter
- inputFill → Color
-
Dedicated fill color for form controls.
final
- muted → Color
-
Generic low-emphasis neutral background.
final
- onPrimary → Color
-
final
- onSecondary → Color
-
final
- primary → Color
-
final
- primarySoft → Color
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondary → Color
-
final
- secondarySoft → Color
-
no setter
- success → Color
-
final
- successSoft → Color
-
no setter
- textDisabled → Color
-
final
- textPrimary → Color
-
final
- textSecondary → Color
-
final
- type → Object
-
The extension's type.
no setterinherited
- warning → Color
-
final
- warningSoft → Color
-
no setter
Methods
-
copyWith(
{Color? primary, Color? onPrimary, Color? secondary, Color? onSecondary, Color? background, Color? card, Color? muted, Color? inputFill, Color? border, Color? textPrimary, Color? textSecondary, Color? textDisabled, Color? icon, Color? success, Color? warning, Color? error, Color? info}) → KiteColors -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(
covariant KiteColors? other, double t) → KiteColors -
Linearly interpolate with another ThemeExtension object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
soft(
Color color, {double amount = 0.12}) → Color -
Creates a fully opaque subtle version of
color. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited