KiteLayoutSize enum
- Inheritance
- Available extensions
Values
- compact → const KiteLayoutSize
- medium → const KiteLayoutSize
- expanded → const KiteLayoutSize
Properties
- compact → bool
-
Available on KiteLayoutSize, provided by the KiteLayoutSizeX extension
no setter - expanded → bool
-
Available on KiteLayoutSize, provided by the KiteLayoutSizeX extension
no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- label → String
-
Available on Enum, provided by the EnumExtensions extension
Returns a human-readable label from the enum case name.no setter - medium → bool
-
Available on KiteLayoutSize, provided by the KiteLayoutSizeX extension
no setter - name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - pageInsets → EdgeInsets
-
Available on KiteLayoutSize, provided by the KiteLayoutSizeX extension
no setter - pagePadding → double
-
Available on KiteLayoutSize, provided by the KiteLayoutSizeX extension
no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wide → bool
-
Available on KiteLayoutSize, provided by the KiteLayoutSizeX extension
no setter
Methods
-
columns(
{int compact = 1, int medium = 2, int expanded = 3}) → int -
Available on KiteLayoutSize, provided by the KiteLayoutSizeX extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
value<
T> ({required T compact, T? medium, T? expanded}) → T -
Available on KiteLayoutSize, provided by the KiteLayoutSizeX extension
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
KiteLayoutSize> - A constant List of the values in this enum, in order of their declaration.