KiteTypography class
Built with Kite 🪁 Flutter foundations, architecture, and developer tooling. Learn more: https://kite.orkitt.dev
- Inheritance
-
- Object
- ThemeExtension<
KiteTypography> - KiteTypography
- Annotations
Constructors
- KiteTypography({required TextStyle display, required TextStyle h1, required TextStyle h2, required TextStyle h3, required TextStyle title, required TextStyle bodyLarge, required TextStyle body, required TextStyle bodySmall, required TextStyle label, required TextStyle labelSmall, required TextStyle caption})
-
const
Properties
- body → TextStyle
-
Default application body text.
final
- bodyLarge → TextStyle
-
Emphasized or spacious body content.
final
- bodySmall → TextStyle
-
Secondary and compact body text.
final
- caption → TextStyle
-
Helper text, metadata, timestamps.
final
- display → TextStyle
-
Hero text, landing pages, large marketing headings.
final
- h1 → TextStyle
-
Primary page heading.
final
- h2 → TextStyle
-
Section heading.
final
- h3 → TextStyle
-
Small section / dialog heading.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → TextStyle
-
Buttons, controls, navigation labels.
final
- labelSmall → TextStyle
-
Chips, tabs, compact controls.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → TextStyle
-
Card titles, list titles, input-related titles.
final
- type → Object
-
The extension's type.
no setterinherited
Methods
-
copyWith(
{TextStyle? display, TextStyle? h1, TextStyle? h2, TextStyle? h3, TextStyle? title, TextStyle? bodyLarge, TextStyle? body, TextStyle? bodySmall, TextStyle? label, TextStyle? labelSmall, TextStyle? caption}) → KiteTypography -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(
covariant KiteTypography? other, double t) → KiteTypography -
Linearly interpolate with another ThemeExtension object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
KiteColors colors) → KiteTypography - Applies the active Kite color palette to typography.
-
toString(
) → String -
A string representation of this object.
inherited
-
toTextTheme(
) → TextTheme
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- standard → const KiteTypography